AndroidIntentOption class

Represents the options for an Android Intent.

This class encapsulates the parameters that can be used to build an Android Intent, allowing for the specification of various intent properties such as action, flags, category, data, and additional arguments. It ensures that at least one of the action or component name is provided to create a valid intent.

See Android Intents for more information on how to use Intents.

Constructors

AndroidIntentOption({String? action, List<int>? flags, String? category, String? data, Map<String, dynamic>? arguments, Map<String, List>? arrayArguments, String? package, String? componentName, String? type})
Creates an instance of AndroidIntentOption with the specified parameters.
const

Properties

action String?
This is the general verb that the intent should attempt to do. This includes constants like ACTION_VIEW.
final
arguments Map<String, dynamic>?
The equivalent of extras, a generic Bundle of data that the Intent can carry. This is a slot for extraneous data that the listener may use.
final
arrayArguments Map<String, List>?
Similar to arguments, but in this case the arguments are an array and will be added to the intent as in an array extra instead of of an array list.
final
category String?
An optional additional constant qualifying the given action.
final
componentName String?
Set the exact ComponentName that should handle the intent. If this is set package should also be non-null.
final
data String?
The Uri that the action is pointed towards.
final
flags List<int>?
Constants that can be set on an intent to tweak how it is finally handled.
final
hashCode int
The hash code for this object.
no setterinherited
package String?
Sets the data to only resolve within this given package.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type String?
Set an explicit MIME data type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited