AppleMapsDirectionsAction class
Apple Maps directions action using addresses/place names.
- Inheritance
- Implemented types
Constructors
- AppleMapsDirectionsAction({required String destination, required bool fallbackToStore, String? origin, AppleMapsTransportType? mode})
- Creates a new AppleMapsDirectionsAction.
Properties
- androidPackageName → String?
-
Android not supported.
no setterinherited
- appLink → Uri
-
The URL used to launch the app with a specific action.
no setteroverride
- customScheme → String
-
Custom URL scheme for Apple Maps.
no setterinherited
- destination → String
-
Destination address or name.
final
- fallbackLink → Uri
-
The fallback web URL to use when the primary action cannot be performed.
no setteroverride
- fallbackToStore ↔ bool
-
Whether to redirect to store when app not installed.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- macosBundleIdentifier → String?
-
macOS bundle identifier for Apple Maps.
no setterinherited
- mode → AppleMapsTransportType?
-
Optional transport type.
final
- origin → String?
-
Optional origin address or name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
storeActions
→ List<
StoreOpenAppPageAction> -
App store actions to open Apple Maps page (iOS only).
no setterinherited
-
supportedPlatforms
→ List<
PlatformType> -
Supported platforms list (iOS and macOS).
no setterinherited
- website → Uri
-
Apple Maps website for fallback.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited