CafeBazaarStore class

Cafe Bazaar Store application for Android.

This class implements the StoreApp interface to provide capabilities for interacting with the Cafe Bazaar store on Android devices. Cafe Bazaar is a popular app store in Iran.

Implemented types
Implementers

Constructors

CafeBazaarStore()
Creates a new CafeBazaarStore instance.
CafeBazaarStore.open()
Creates an action to open the Cafe Bazaar app.
factory

Properties

androidPackageName String?
The Android package name for the Cafe Bazaar app.
no setteroverride
customScheme String?
The custom URL scheme for the Cafe Bazaar app (not applicable for other platforms).
getter/setter pairoverride-getter
hashCode int
The hash code for this object.
no setterinherited
macosBundleIdentifier String?
The MacOS bundle identifier for the Cafe Bazaar app (not applicable for Android).
no setteroverride
platform PlatformType
The platform this store app is associated with (Android).
getter/setter pairoverride-getter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportedPlatforms List<PlatformType>
The platforms that the Cafe Bazaar app supports.
no setteroverride
website Uri
The web URL for the Cafe Bazaar store.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

openAppPage({required String packageName, String? referrer}) CafeBazaarStoreOpenAppPageAction
Creates an action to open a specific app's page in the Cafe Bazaar store.