platform property
The platform this store app is associated with (Android).
Implementation
@override
PlatformType platform = PlatformType.android;
The platform this store app is associated with (Android).
@override
PlatformType platform = PlatformType.android;