Fallbackable class abstract

Represents an entity that provides a fallback URL.

This interface is used by actions that can provide a web fallback when a native app action cannot be performed.

Implementers

Constructors

Fallbackable()

Properties

The fallback web URL to use when the primary action cannot be performed.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited