LinkedInOpenCompanyAction class
An action to open a specific company page in the LinkedIn app.
This class extends LinkedIn and implements multiple interfaces to provide comprehensive functionality for opening company pages with fallback support.
- Inheritance
- Implemented types
Constructors
- LinkedInOpenCompanyAction({required String companyId, required bool fallbackToStore})
- Creates a new LinkedInOpenCompanyAction instance.
Properties
- androidPackageName → String
-
The Android package name for the LinkedIn app.
no setterinherited
- companyId → String
-
The company ID of the company page to open.
final
- customScheme → String
-
The custom URL scheme for the LinkedIn app.
no setterinherited
- fallbackLink → Uri
-
The fallback link to use when the LinkedIn app cannot be opened.
no setteroverride
- fallbackToStore ↔ bool
-
Whether to automatically redirect to app stores when the LinkedIn app is not installed.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- macosBundleIdentifier ↔ String?
-
The MacOS bundle identifier for the LinkedIn app.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
storeActions
→ List<
StoreOpenAppPageAction> -
A list of actions to open the LinkedIn app's page in various app stores.
no setterinherited
-
supportedPlatforms
→ List<
PlatformType> -
The platforms that the LinkedIn app supports.
no setterinherited
- universalLink → Uri
-
The universal link URL for opening the specified company page in the LinkedIn app.
no setteroverride
- website → Uri
-
The web URL for LinkedIn.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited