SlackOpenChannelAction class

Action to open a Slack channel.

Inheritance
Implemented types

Constructors

SlackOpenChannelAction({required String teamId, required String channelId, required bool fallbackToStore})
Creates a new SlackOpenChannelAction.

Properties

androidPackageName String
The Android package name for the application.
no setterinherited
The URL used to launch the app with a specific action.
no setteroverride
channelId String
The channel ID to open.
final
customScheme String
The custom URL scheme for the application.
no setterinherited
The fallback web URL to use when the primary action cannot be performed.
no setteroverride
fallbackToStore bool
Whether to automatically fall back to store links when the app is not installed.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
macosBundleIdentifier String
The MacOS bundle identifier for the application.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storeActions List<StoreOpenAppPageAction>
A list of actions to open this app's page in various app stores.
no setterinherited
supportedPlatforms List<PlatformType>
The platforms that the application supports.
no setterinherited
teamId String
The team ID of the workspace.
final
website Uri
The web URL for the application.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited