TencentMapsDirectionsWithCoordsAction class
Builds a coordinate route in Tencent Maps.
- Inheritance
-
- Object
- App
- TencentMaps
- TencentMapsDirectionsWithCoordsAction
- Implemented types
Constructors
-
TencentMapsDirectionsWithCoordsAction({required Coordinate destination, required String referer, required TencentMapsTravelMode mode, required TencentMapsCoordType coordType, required bool fallbackToStore, Coordinate? origin, String? destinationTitle, String? originTitle, String? destinationPoiId, List<
TencentMapsWaypoint> waypoints = const []}) - Creates a new TencentMapsDirectionsWithCoordsAction.
Properties
- androidIntentOptions → AndroidIntentOption
-
The Android Intent options for launching this action on Android devices.
no setteroverride
- androidPackageName → String
-
Android package name.
no setterinherited
- appLink → Uri
-
An optional app link that can be used on non-Android platforms.
no setteroverride
- coordType → TencentMapsCoordType
-
Coordinate type used by the web fallback.
final
- customScheme → String
-
Custom scheme.
no setterinherited
- destination → Coordinate
-
Destination coordinate.
final
- destinationPoiId → String?
-
Optional destination POI ID used by the native app.
final
- destinationTitle → String?
-
Optional destination title.
final
- fallbackLink → Uri
-
The fallback web URL to use when the primary action cannot be performed.
no setteroverride
- fallbackToStore ↔ bool
-
Whether to redirect to a store listing when the native app is missing.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- macosBundleIdentifier → String?
-
macOS is not supported.
no setterinherited
- mode → TencentMapsTravelMode
-
Route mode.
final
- origin → Coordinate?
-
Optional origin coordinate. When null, Tencent Maps uses current location.
final
- originTitle → String?
-
Optional origin title.
final
- referer → String
-
Tencent developer key.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
storeActions
→ List<
StoreOpenAppPageAction> -
Store actions for Tencent Maps.
no setterinherited
-
supportedPlatforms
→ List<
PlatformType> -
Supported mobile platforms.
no setterinherited
-
waypoints
→ List<
TencentMapsWaypoint> -
Optional native waypoints, up to 15.
final
- website → Uri
-
Official Tencent Maps cross-platform download page.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited