ThreadsCreatePostAction class

An action to open the Threads compose flow with prefilled text.

Inheritance
Implemented types

Constructors

ThreadsCreatePostAction({required String text, required bool fallbackToStore})
Creates a new ThreadsCreatePostAction instance.

Properties

androidIntentOptions AndroidIntentOption
The Android Intent options for launching this action on Android devices.
no setteroverride
androidPackageName String
The Android package name for the Threads app.
no setterinherited
The app link URL for opening the compose flow in the Threads app.
no setteroverride
customScheme String
The custom URL scheme for the Threads app.
no setterinherited
The fallback link to use when the Threads app cannot be opened.
no setteroverride
fallbackToStore bool
Whether to automatically redirect to app stores when the Threads app is not installed.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
macosBundleIdentifier String?
The MacOS bundle identifier for the Threads app.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storeActions List<StoreOpenAppPageAction>
A list of actions to open the Threads app's page in various app stores.
no setterinherited
supportedPlatforms List<PlatformType>
The platforms that the Threads app supports.
no setterinherited
text String
The text to prefill in the compose flow.
final
website Uri
The web URL for Threads.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited