WazeSearchAction class
Waze search action using universal link. No web fallback provided.
- Inheritance
- Implemented types
Constructors
- WazeSearchAction({required String query, required bool fallbackToStore})
- Creates a new WazeSearchAction.
Properties
- androidPackageName → String
-
Android package of Waze.
no setterinherited
- customScheme → String
-
Custom URL scheme of Waze for installation checks.
no setterinherited
- fallbackToStore ↔ bool
-
Whether to redirect to store when app not installed.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- macosBundleIdentifier ↔ String?
-
macOS not supported for Waze.
getter/setter pairinherited
- query → String
-
Search query string (q).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
storeActions
→ List<
StoreOpenAppPageAction> -
App store actions to open Waze app page.
no setterinherited
-
supportedPlatforms
→ List<
PlatformType> -
Supported platforms.
no setterinherited
- universalLink → Uri
-
The universal link URL used to launch the app with a specific action.
no setteroverride
- website → Uri
-
Waze website.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited