WhatsApp class

WhatsApp application.

This class implements the DownloadableApp interface to provide capabilities for interacting with the WhatsApp app on various platforms.

Inheritance
Implemented types
Implementers

Constructors

WhatsApp({bool fallbackToStore = false})
Creates a new WhatsApp instance.
WhatsApp.open({bool fallbackToStore = false})
Creates an action to open the WhatsApp app.
factory

Properties

androidPackageName String
The Android package name for the WhatsApp app.
no setteroverride
customScheme String
The custom URL scheme for the WhatsApp app.
no setteroverride
fallbackToStore bool
Whether to automatically redirect to app stores when the WhatsApp app is not installed.
getter/setter pairoverride-getter
hashCode int
The hash code for this object.
no setterinherited
macosBundleIdentifier String?
The MacOS bundle identifier for the WhatsApp app.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storeActions List<StoreOpenAppPageAction>
A list of actions to open the WhatsApp app's page in various app stores.
no setteroverride
supportedPlatforms List<PlatformType>
The platforms that the WhatsApp app supports.
no setteroverride
website Uri
The web URL for WhatsApp.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

chat({required String phoneNumber, String? message, bool fallbackToStore = false}) WhatsAppChatAction
Creates an action to start a chat with a specific phone number in the WhatsApp app.
shareText({required String text, bool fallbackToStore = false}) WhatsAppShareTextAction
Creates an action to share text via the WhatsApp app.