WhatsAppShareTextAction class

An action to share text via the WhatsApp app.

This class extends WhatsApp and implements multiple interfaces to provide comprehensive functionality for sharing text with fallback support.

Inheritance
Implemented types

Constructors

WhatsAppShareTextAction({required String text, required bool fallbackToStore})
Creates a new WhatsAppShareTextAction instance.

Properties

androidPackageName String
The Android package name for the WhatsApp app.
no setterinherited
The app link URL for sharing text via the WhatsApp app.
no setteroverride
customScheme String
The custom URL scheme for the WhatsApp app.
no setterinherited
The fallback link to use when the WhatsApp app cannot be opened.
no setteroverride
fallbackToStore bool
Whether to automatically redirect to app stores when the WhatsApp app is not installed.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
macosBundleIdentifier String?
The MacOS bundle identifier for the WhatsApp app.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storeActions List<StoreOpenAppPageAction>
A list of actions to open the WhatsApp app's page in various app stores.
no setterinherited
supportedPlatforms List<PlatformType>
The platforms that the WhatsApp app supports.
no setterinherited
text String
The text to share.
final
website Uri
The web URL for WhatsApp.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited