arguments property
The equivalent of extras, a generic Bundle of data that the Intent can
carry. This is a slot for extraneous data that the listener may use.
If the argument contains a list value, then the value will be put in as an array list.
Implementation
final Map<String, dynamic>? arguments;