App class abstract
Represents a generic application that can be launched.
This interface defines the basic properties needed to identify and launch an application across different platforms.
Constructors
- App()
Properties
- androidPackageName → String?
-
The Android package name for the application.
no setter
- customScheme → String?
-
The custom URL scheme for the application.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- macosBundleIdentifier → String?
-
The MacOS bundle identifier for the application.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
supportedPlatforms
→ List<
PlatformType> -
The platforms that the application supports.
no setter
- website → Uri
-
The web URL for the application.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited