AppLinkAppAction class abstract
Represents an app action that uses a standard app link.
This interface extends AppAction to define actions that can be performed using a direct app link URL format. App links are a common way to launch apps with specific actions on various platforms.
- Inheritance
- Implementers
- AppleMapsDirectionsAction
- AppleMapsDirectionsWithCoordsAction
- AppleMapsSearchAction
- AppleMapsViewAction
- FacebookOpenProfileByIdAction
- GoogleMapsDirectionsAction
- GoogleMapsDirectionsWithCoordsAction
- GoogleMapsSearchAction
- GoogleMapsViewAction
- HuaweiAppGalleryStoreOpenAppPageAction
- InstagramOpenProfileAction
- IOSAppStoreOpenAppPageAction
- IOSAppStoreRateAppAction
- MacAppStoreOpenAppPageAction
- MacAppStoreRateAppAction
- MicrosoftStoreOpenAppPageAction
- MicrosoftStoreRateAppAction
- MyketStoreOpenAppPageAction
- MyketStoreRateAppAction
- PinterestOpenBoardAction
- PinterestOpenPinAction
- PinterestOpenProfileAction
- PinterestSearchAction
- SlackOpenChannelAction
- SlackOpenTeamAction
- SlackOpenUserAction
- SygicDirectionsWithCoordsAction
- SygicViewAction
- TelegramOpenProfileAction
- TelegramOpenProfileByPhoneNumberAction
- TelegramSendMessageAction
- TelegramSendMessageByPhoneNumberAction
- TwitterOpenProfileAction
- TwitterOpenTweetAction
- WhatsAppChatAction
- WhatsAppShareTextAction
- ZoomJoinMeetingAction
Constructors
Properties
- androidPackageName → String?
-
The Android package name for the application.
no setterinherited
- appLink → Uri
-
The URL used to launch the app with a specific action.
no setter
- customScheme → String?
-
The custom URL scheme for the application.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- macosBundleIdentifier → String?
-
The MacOS bundle identifier for the application.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
supportedPlatforms
→ List<
PlatformType> -
The platforms that the application supports.
no setterinherited
- website → Uri
-
The web URL for the application.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited