IntentAppLinkAction class abstract
Represents an app action that uses Android Intent options.
This interface extends AppAction to define actions that can be performed using Android-specific Intent features. It provides the ability to use the more powerful Intent system on Android while falling back to regular app links on other platforms.
- Inheritance
- Implementers
- AmapDirectionsAction
- AmapDirectionsWithCoordsAction
- AmapMyLocationAction
- AmapSearchAction
- AmapViewAction
- BaiduMapsDirectionsAction
- BaiduMapsDirectionsWithCoordsAction
- BaiduMapsLineAction
- BaiduMapsNavigateAction
- BaiduMapsNearbySearchAction
- BaiduMapsSearchAction
- BaiduMapsViewAction
- CafeBazaarStoreOpenAppPageAction
- GoogleMapsDirectionsAction
- GoogleMapsDirectionsWithCoordsAction
- GoogleMapsSearchAction
- GoogleMapsViewAction
- MoovitDirectionsWithCoordsAction
- MoovitViewAction
- NeshanDirectionsWithCoordsAction
- NeshanViewAction
- TencentMapsDirectionsWithCoordsAction
- TencentMapsNearbySearchAction
- TencentMapsSearchAction
- TencentMapsViewAction
- ThreadsCreatePostAction
- ThreadsOpenPostAction
- ThreadsOpenProfileAction
- ThreadsOpenTagAction
- ThreadsSearchAction
- TwoGisDirectionsWithCoordsAction
- TwoGisViewAction
- YandexMapsDirectionsWithCoordsAction
- YandexMapsOpenMapAction
- YandexMapsOrganizationAction
- YandexMapsPanoramaAction
- YandexMapsSearchAction
- YandexMapsViewAction
- YandexMapsWhatIsHereAction
- YandexNavigatorDirectionsWithCoordsAction
- YandexNavigatorSearchAction
- YandexNavigatorViewAction
Constructors
Properties
- androidIntentOptions → AndroidIntentOption
-
The Android Intent options for launching this action on Android devices.
no setter
- androidPackageName → String?
-
The Android package name for the application.
no setterinherited
- appLink → Uri?
-
An optional app link that can be used on non-Android platforms.
no setter
- customScheme → String?
-
The custom URL scheme for the application.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- macosBundleIdentifier → String?
-
The MacOS bundle identifier for the application.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
supportedPlatforms
→ List<
PlatformType> -
The platforms that the application supports.
no setterinherited
- website → Uri
-
The web URL for the application.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited