androidIntentOptions property
AndroidIntentOption
get
androidIntentOptions
The Android Intent options for launching this action on Android devices.
This contains the specific Intent configuration needed for Android platforms.
Implementation
AndroidIntentOption get androidIntentOptions;