MapViewAction class abstract
Represents a map action that displays a coordinate.
- Inheritance
-
- Object
- App
- DownloadableApp
- MapAppAction
- MapViewAction
- Implementers
Constructors
Properties
- androidPackageName → String?
-
The Android package name for the application.
no setterinherited
- coordinate → Coordinate
-
Coordinate to display on the map.
no setter
- customScheme → String?
-
The custom URL scheme for the application.
no setterinherited
- fallbackToStore → bool
-
Whether to automatically fall back to store links when the app is not installed.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- macosBundleIdentifier → String?
-
The MacOS bundle identifier for the application.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
storeActions
→ List<
StoreOpenAppPageAction> -
A list of actions to open this app's page in various app stores.
no setterinherited
-
supportedPlatforms
→ List<
PlatformType> -
The platforms that the application supports.
no setterinherited
- website → Uri
-
The web URL for the application.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited