ThreadsOpenPostAction class
An action to open a specific post in the Threads app.
- Inheritance
- Implemented types
- Implementers
Constructors
- ThreadsOpenPostAction({required String username, required String postId, required bool fallbackToStore})
- Creates a new ThreadsOpenPostAction instance.
Properties
- androidIntentOptions → AndroidIntentOption
-
The Android Intent options for launching this action on Android devices.
no setteroverride
- androidPackageName → String
-
The Android package name for the Threads app.
no setterinherited
- appLink → Uri
-
An optional app link that can be used on non-Android platforms.
no setteroverride
- customScheme → String
-
The custom URL scheme for the Threads app.
no setterinherited
- fallbackLink → Uri
-
The fallback link to use when the Threads app cannot be opened.
no setteroverride
- fallbackToStore ↔ bool
-
Whether to automatically redirect to app stores when the Threads app is not installed.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- macosBundleIdentifier ↔ String?
-
The MacOS bundle identifier for the Threads app.
getter/setter pairinherited
- postId → String
-
The post identifier.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
storeActions
→ List<
StoreOpenAppPageAction> -
A list of actions to open the Threads app's page in various app stores.
no setterinherited
-
supportedPlatforms
→ List<
PlatformType> -
The platforms that the Threads app supports.
no setterinherited
- universalLink → Uri
-
The universal link URL for the specified Threads post.
no setteroverride
- username → String
-
The username that owns the post.
final
- website → Uri
-
The web URL for Threads.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited